@@ -1,6 +1,7 @@
 var fs = require("fs"),
 	utils = require("./utils"),
-	path = require("path");
+	path = require("path"),
+	Faces = require("./faces");
 
 var views = {
 	"ascii": fs.readFileSync( path.join( __dirname, "/../", "schema/ascii.json"), 'utf8'),
@@ -19,7 +20,18 @@ Ascii.prototype.compile = function( data ){
 	// - adding meta info
 	data = this.meta( data );
 	// - fix faces
-	data.faces = faces( data.faces );
+	data.faces = fixFaces( data.faces );
+	// - alignment
+	var faces = new Faces( this.options );
+	if( this.options.align == "center" ){
+		data.vertices = faces.center( data.vertices );
+	} else if( this.options.align == "centerxz" ){
+		data.vertices = faces.centerxz( data.vertices );
+	} else if( this.options.align == "bottom" ){
+		data.vertices = faces.bottom( data.vertices );
+	} else if( this.options.align == "top" ){
+		data.vertices = faces.top( data.vertices );
+	}
 	// - moph targets (fallback)
 	data.morphTargets = data.morphTargets || " ";
 	data.morphColors = data.morphColors || " ";
@@ -53,7 +65,7 @@ Ascii.prototype.meta = function( data ){
 
 // Internal methods
 
-function faces( data ){
+function fixFaces( data ){
 	var faces = [];
 	for( var i in data ){
 		faces.push( generate_face(data[i]) );
@@ -153,4 +165,4 @@ function setBit(value, position, on){
 	}
 }
 
-module.exports = Ascii;
\ No newline at end of file
+module.exports = Ascii;
