@@ -57,17 +57,16 @@ Binary.prototype = {
 
 		var buffer, nnormals;
 		var faces = new Faces( this.options );
-
-		/*
-		if ALIGN == "center":
-			center(vertices)
-		elif ALIGN == "centerxz":
-			centerxz(vertices)
-		elif ALIGN == "bottom":
-			bottom(vertices)
-		elif ALIGN == "top":
-			top(vertices)
-		*/
+		// - alignment
+		if( this.options.align == "center" ){
+			data.vertices = faces.center( data.vertices );
+		} else if( this.options.align == "centerxz" ){
+			data.vertices = faces.centerxz( data.vertices );
+		} else if( this.options.align == "bottom" ){
+			data.vertices = faces.bottom( data.vertices );
+		} else if( this.options.align == "top" ){
+			data.vertices = faces.top( data.vertices );
+		}
 
 		var sfaces = faces.sort( data.faces );
 
@@ -77,7 +76,6 @@ Binary.prototype = {
 			nnormals = 0;
 		}
 
-
 		var ntri_flat = sfaces['triangles_flat'].length;
 		var ntri_smooth = sfaces['triangles_smooth'].length;
 		var ntri_flat_uv = sfaces['triangles_flat_uv'].length;
@@ -141,9 +139,7 @@ Binary.prototype = {
 			for( var i = 0; i < data.normals.length; i +=3 ){
 				var n = [ data.normals[i], data.normals[i+1], data.normals[i+2] ];
 				n = utils.normalize(n);
-				var oct = struct.pack('<bbb', [Math.floor(n[0]*127+0.5),
-										   Math.floor(n[1]*127+0.5),
-										   Math.floor(n[2]*127+0.5)]);
+				var oct = struct.pack('<bbb', [Math.floor(n[0]*127+0.5), Math.floor(n[1]*127+0.5), Math.floor(n[2]*127+0.5)]);
 				buffer = Buffer.concat([ buffer, oct ]);
 			}
 			buffer = add_padding(buffer, nnormals * 3);
